==> powermanim-0.0.10-py3-none-any.whl: powermanim/layouts/arrangedbullets.py <==
import typing as T
from collections import defaultdict

from manim import *


class MathBullet(MathTex):
    def __init__(
        self,
        *text: str,
        level: int = 0,
        group: T.Optional[int] = None,
        adjustment: float = 0.0,
        symbol: T.Optional[str] = r"\bullet",
        autoplace: bool = True,
        **kwargs,
    ):
        """A class to represent a bullet point.

        Args:
            text: The text to be displayed.
            level: The indent level of the bullet point.
            group: The group the bullet point belongs to, controls the animations.
            adjustment: The adjustment of the bullet.
            symbol: The symbol to be displayed as the bullet.
            autoplace: Whether to automatically place the bullet point.
        """
        self.level = level
        self.adjustment = adjustment
        self.group = group
        self.symbol = symbol
        self.autoplace = autoplace

        first_text, *rest_text = text
        if symbol is not None:
            first_text = rf"{symbol}~{first_text}"

        super().__init__(first_text, *rest_text, **kwargs)

    def indent(self, indent_buff: float = MED_LARGE_BUFF * 1.5):
        """Indent the bullet point.

        Args:
            indent_buff: The spacing between the bullet and the text.
        """
        self.shift(RIGHT * indent_buff * self.level)

    def unindent(self, indent_buff: float = MED_LARGE_BUFF * 1.5):
        """Unindent the bullet point.

        Args:
            indent_buff: The spacing between the bullet and the text.
        """
        self.shift(LEFT * indent_buff * self.intend_level)

    def adjust(self, adjustment: T.Optional[float] = None):
        """Adjust the bullet point.

        Args:
            adjustment: The shift of the bullet.
        """
        if adjustment is None:
            adjustment = self.adjustment
        self.shift(self.adjustment)


class Bullet(MathBullet):
    def __init__(
        self,
        *text: str,
        level: int = 0,
        group: T.Optional[int] = None,
        adjustment: float = 0.0,
        symbol: T.Optional[str] = r"$\bullet$",
        force_inline: bool = False,
        arg_separator="",
        tex_environment="center",
        **kwargs,
    ):
        first_text, *rest_text = text
        if force_inline:
            first_text = r"\mbox{" + first_text
            rest_text = *rest_text, r"}"

        super().__init__(
            first_text,
            *rest_text,
            level=level,
            group=group,
            adjustment=adjustment,
            symbol=symbol,
            arg_separator=arg_separator,
            tex_environment=tex_environment,
            **kwargs,
        )


class ArrangedBullets(VGroup):
    def arrage_rows(self, rows: T.Iterable[T.Union[MathBullet, Bullet, MathTex, Tex, Text]]):
        bullet_rows: T.Iterable[MathBullet] = (
            VGroup(*rows)
            .arrange(DOWN, aligned_edge=LEFT, buff=self.line_spacing)
            .to_edge(LEFT, buff=self.left_buff)
            .shift(self.global_shift)
        )

        for row in bullet_rows:
            row.indent(indent_buff=self.indent_buff)
            row.adjust()

    def __init__(
        self,
        *rows: T.Union[MathBullet, Bullet, MathTex, Tex, Text],
        line_spacing: float = MED_LARGE_BUFF * 1.5,
        indent_buff: float = MED_LARGE_BUFF * 1.5,
        left_buff: float = MED_LARGE_BUFF * 1.5,
        global_shift: float = 0.0,
    ):
        """A VGroup that arranges the rows in a list of bullet points.

        Args:
            rows: A list of items to be displayed.
            line_spacing: The spacing between the rows.
            indent_buff: The spacing between the bullet and the text.
            left_buff: The spacing between the left edge of the rows and the left edge of the screen.
            global_shift: The global_shift of the rows.
        """
        self.line_spacing = line_spacing
        self.indent_buff = indent_buff
        self.left_buff = left_buff
        self.global_shift = global_shift

        rows = [(row if isinstance(row, MathBullet) else Bullet(row)) for row in rows]

        self.arrage_rows((row for row in rows if row.autoplace))

        groups = [row.group for row in rows]

        # If there is a None and aso something else
        if (None in groups) and len(set(groups)) != 1:
            raise ValueError("The groups must be specified for all or no bullets at all.")

        group2bullet = defaultdict(list)
        for i, row in enumerate(rows):
            group = row.group
            if group is None:
                group = i
            group2bullet[group].append(row)

        group_rows = []
        for _, bullets in group2bullet.items():
            group_rows.append(VGroup(*bullets))

        super().__init__(*group_rows)
        self.ngroups = len(self)

==> powermanim-0.1.0-py3-none-any.whl: powermanim/layouts/arrangedbullets.py <==
import typing as T

from manim import *


class MathBullet(MathTex):
    def __init__(
        self,
        *text: str,
        level: int = 0,
        group: T.Optional[int] = None,
        adjustment: float = 0.0,
        symbol: T.Optional[str] = r"\bullet",
        autoplace: bool = True,
        **kwargs,
    ):
        """A class to represent a bullet point.

        Args:
            text: The text to be displayed.
            level: The indent level of the bullet point.
            group: The group the bullet point belongs to, controls the animations.
            adjustment: The adjustment of the bullet.
            symbol: The symbol to be displayed as the bullet.
            autoplace: Whether to automatically place the bullet point.
        """
        self.level = level
        self.adjustment = adjustment
        self.group = group
        self.symbol = symbol
        self.autoplace = autoplace

        first_text, *rest_text = text
        if symbol is not None:
            first_text = rf"{symbol}~{first_text}"

        super().__init__(first_text, *rest_text, **kwargs)

    def indent(self, indent_buff: float = MED_LARGE_BUFF * 1.5):
        """Indent the bullet point.

        Args:
            indent_buff: The spacing between the bullet and the text.
        """
        self.shift(RIGHT * indent_buff * self.level)

    def unindent(self, indent_buff: float = MED_LARGE_BUFF * 1.5):
        """Unindent the bullet point.

        Args:
            indent_buff: The spacing between the bullet and the text.
        """
        self.shift(LEFT * indent_buff * self.intend_level)

    def adjust(self, adjustment: T.Optional[float] = None):
        """Adjust the bullet point.

        Args:
            adjustment: The shift of the bullet.
        """
        if adjustment is None:
            adjustment = self.adjustment
        self.shift(self.adjustment)


class Bullet(MathBullet):
    def __init__(
        self,
        *text: str,
        level: int = 0,
        group: T.Optional[int] = None,
        adjustment: float = 0.0,
        symbol: T.Optional[str] = r"$\bullet$",
        force_inline: bool = False,
        arg_separator="",
        tex_environment="center",
        **kwargs,
    ):
        first_text, *rest_text = text
        if force_inline:
            first_text = r"\mbox{" + first_text
            rest_text = *rest_text, r"}"

        super().__init__(
            first_text,
            *rest_text,
            level=level,
            group=group,
            adjustment=adjustment,
            symbol=symbol,
            arg_separator=arg_separator,
            tex_environment=tex_environment,
            **kwargs,
        )


class ArrangedBullets(VGroup):
    def arrage_rows(self, rows: T.Iterable[T.Union[MathBullet, Bullet, MathTex, Tex, Text]]):
        bullet_rows: T.Iterable[MathBullet] = (
            VGroup(*rows)
            .arrange(DOWN, aligned_edge=LEFT, buff=self.line_spacing)
            .to_edge(LEFT, buff=self.left_buff)
            .shift(self.global_shift)
        )

        for row in bullet_rows:
            row.indent(indent_buff=self.indent_buff)
            row.adjust()

    def __init__(
        self,
        *rows: T.Union[MathBullet, Bullet, MathTex, Tex, Text],
        line_spacing: float = MED_LARGE_BUFF * 1.5,
        indent_buff: float = MED_LARGE_BUFF * 1.5,
        left_buff: float = MED_LARGE_BUFF * 1.5,
        global_shift: float = 0.0,
    ):
        """A VGroup that arranges the rows in a list of bullet points.

        Args:
            rows: A list of items to be displayed.
            line_spacing: The spacing between the rows.
            indent_buff: The spacing between the bullet and the text.
            left_buff: The spacing between the left edge of the rows and the left edge of the screen.
            global_shift: The global_shift of the rows.
        """
        self.line_spacing = line_spacing
        self.indent_buff = indent_buff
        self.left_buff = left_buff
        self.global_shift = global_shift

        rows = [(row if isinstance(row, MathBullet) else Bullet(row)) for row in rows]

        self.arrage_rows((row for row in rows if row.autoplace))
        super().__init__(*rows)
